@@ -1,5 +1,5 @@
 /*
- MRTG 2.8.9  -- Rateup
+ MRTG 2.8.12  -- Rateup
  *********************
 
  Rateup is a fast add-on to the great MRTG Traffic monitor.  It makes
@@ -60,7 +60,7 @@
 #include <gd.h>
 #include <gdfonts.h>
 
-char *VERSION = "2.8.9";
+char *VERSION = "2.8.12";
 char *program,*router,*routerpath;
 int histvalid;
 int dorelpercent = 0;
@@ -109,6 +109,7 @@ int col_outp[3];
 
 long	kilo = (long)1000;
 char*   kMG = (char*) NULL;
+char*   kMGcopy = (char*) NULL; /* JML bugfix */
 int	kMGnumber = 0;
 
 #define MAXL	200	/* Maximum length of last in & out fields */
@@ -234,7 +235,7 @@ int peak;
     /* position the graph */
 #define ytr(y) (unsigned long)(maxy*yscale+14-((y)*yscale))
     /* translate x/y coord into graph coord */
-#define xtr(x) (unsigned long)((growright) ? (maxx*xscale+77-((x)*xscale)) : (77+((x)*xscale))) 
+#define xtr(x) (unsigned long)((growright) ? (maxx*xscale+81-((x)*xscale)) : (81+((x)*xscale))) 
     /* ################################################# */ 
 
     /* GD LIB declarations */
@@ -372,7 +373,8 @@ int peak;
 
     if (kMG) {
        int count = (int)digits;
-       short_si_out = kMG;
+       short_si_out = kMGcopy;                /* JML bugfix */
+       strcpy(kMGcopy,kMG);           /* JML bugfix */
        while (count >= 3) {
           count -= 3;
           short_si_out = strchr(short_si_out, ',')+1;
@@ -1326,6 +1328,7 @@ char **argv;
 	    case 'K':
 		kMG = calloc(strlen(argv[argi+1])+1, sizeof(char));
 		strcpy (kMG, argv[argi+1]);
+                kMGcopy = calloc(strlen(argv[argi+1])+1, sizeof(char));               
 		used = 2;
 		break;
             case 'l':  /* YLegend - rewritten by Oliver Haid */
